netapp_ontap.models.vsi_on_nas API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.vsi_on_nas`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VsiOnNasSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VsiOnNas object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `datastore: VsiOnNasDatastore GET POST PATCH`

    The datastore field of the vsi_on_nas.

  `hyper_v_access: VdiOnNasHyperVAccess GET POST`

    The hyper_v_access field of the vsi_on_nas.

  `nfs_access: List[AppNfsAccess] GET POST`

    The list of NFS access controls. You must provide either 'host' or 'access' to enable NFS access.

  `protection_type: MongoDbOnSanProtectionType GET POST PATCH`

    The protection_type field of the vsi_on_nas.